pub struct BitmapScale {
pub hori: SbitLineMetrics,
pub vert: SbitLineMetrics,
pub ppem_x: u8,
pub ppem_y: u8,
pub substitute_ppem_x: u8,
pub substitute_ppem_y: u8,
}Expand description
One BitmapScale record (5.6.4) — a single synthesised strike defined
as a scaled copy of an existing EBLC/EBDT strike.
Fields
hori: SbitLineMetricsFont-wide horizontal line metrics for the scaled strike.
vert: SbitLineMetricsFont-wide vertical line metrics for the scaled strike.
ppem_x: u8Target (synthesised) horizontal pixels-per-em.
ppem_y: u8Target (synthesised) vertical pixels-per-em.
substitute_ppem_x: u8Horizontal ppem of the real strike to scale from.
substitute_ppem_y: u8Vertical ppem of the real strike to scale from.